/**
 * 파일명: admin.js
 * 위치: /wp-content/plugins/wp-kakao-login/assets/js/
 * 기능: 카카오 로그인 관리자 페이지 JavaScript 기능
 * 작성일: 2025-05-02
 */

(function($) {
    'use strict';
    
    // 페이지 로드 완료 시 실행
    $(document).ready(function() {
        console.log('Kakao Login Admin Script Loaded');
        
        // Client Secret 토글 기능
        $('#toggle-client-secret').on('click', function(e) {
            e.preventDefault();
            
            var secretField = $('#kakao_client_secret');
            var toggleButton = $(this).find('.dashicons');
            
            if (secretField.attr('type') === 'password') {
                secretField.attr('type', 'text');
                toggleButton.removeClass('dashicons-visibility').addClass('dashicons-hidden');
            } else {
                secretField.attr('type', 'password');
                toggleButton.removeClass('dashicons-hidden').addClass('dashicons-visibility');
            }
        });
        
        // 리다이렉트 URI 복사 기능
        $('#copy-redirect-uri').on('click', function(e) {
            e.preventDefault();
            
            var redirectUriField = $('#kakao_redirect_uri');
            
            // 텍스트 필드 선택
            redirectUriField.select();
            
            try {
                // 클립보드에 복사
                var successful = document.execCommand('copy');
                var msg = successful ? '클립보드에 복사되었습니다!' : '복사에 실패했습니다. 수동으로 복사해주세요.';
                
                // 알림 표시
                var $notice = $('<div class="notice notice-success is-dismissible"><p>' + msg + '</p></div>')
                    .hide()
                    .insertAfter($(this))
                    .slideDown();
                
                // 3초 후 알림 삭제
                setTimeout(function() {
                    $notice.slideUp(function() {
                        $(this).remove();
                    });
                }, 3000);
            } catch (err) {
                console.error('클립보드 복사 오류:', err);
                alert('클립보드 복사에 실패했습니다. 수동으로 복사해주세요.');
            }
        });
        
        // 탭 전환 기능
        $('.nav-tab').on('click', function() {
            var tabId = $(this).attr('href').split('=').pop();
            console.log('Tab clicked:', tabId);
            
            // URL에 탭 ID 추가
            window.history.pushState({}, '', $(this).attr('href'));
            
            // 현재 URL에서 탭 ID 가져오기
            var currentTab = window.location.href.split('tab=').pop() || 'settings';
            
            // 활성 탭 표시
            $('.nav-tab').removeClass('nav-tab-active');
            $('.nav-tab[href$="tab=' + currentTab + '"]').addClass('nav-tab-active');
            
            // 탭 내용 표시
            $('.tab-content').hide();
            $('#' + currentTab + '-tab').show();
        });
    });
})(jQuery);