<?php
/*
 * 파일명: direct-kakao-login.php
 * 위치: /wp-content/plugins/wp-kakao-login/
 * 기능: 카카오 로그인 직접 접근 페이지
 * 작성일: 2025-05-01
 * 수정일: 2025-05-02
 */

// ===================================
// 워드프레스 로드 및 함수 포함 (로그 대신 일시적으로 에러 보고 사용)
// ===================================
// 워드프레스 로드
require_once(dirname(dirname(dirname(dirname(__FILE__)))) . '/wp-load.php');

// 필요한 파일 로드 (functions.php가 wp_kakao_login_debug_log 함수를 포함)
require_once(plugin_dir_path(__FILE__) . 'includes/functions.php');

// 이제 로그 함수를 사용할 수 있음
wp_kakao_login_debug_log('Direct Kakao Login Page Accessed');

// 이미 로그인한 사용자는 홈페이지 또는 관리자 페이지로 리다이렉트
if (is_user_logged_in()) {
    $redirect_to = isset($_GET['redirect_to']) ? esc_url_raw($_GET['redirect_to']) : '';
    if (empty($redirect_to)) {
        if (current_user_can('manage_options')) {
            $redirect_to = admin_url();
        } else {
            $redirect_to = home_url();
        }
    }
    wp_redirect($redirect_to);
    exit;
}

// 플러그인 URL 구하기
$plugin_url = plugin_dir_url(__FILE__);

// 옵션 가져오기
$options = get_option('wp_kakao_login_options', array());
$client_id = isset($options['kakao_client_id']) ? $options['kakao_client_id'] : '';

// 콜백 URL을 직접 접근 파일로 설정
$redirect_uri = $plugin_url . 'direct-kakao-callback.php';

// 리다이렉트 URL (로그인 후 이동할 페이지)
$return_url = isset($_GET['redirect_to']) ? esc_url_raw($_GET['redirect_to']) : '';
if (empty($return_url)) {
    // 관리자 페이지로 오는 요청인지 확인
    $referrer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';
    if (strpos($referrer, 'wp-login.php') !== false || strpos($referrer, 'wp-admin') !== false) {
        // 관리자 페이지 관련 요청이면 관리자 페이지로 리다이렉트
        $return_url = admin_url();
    } else {
        // 그 외에는 홈페이지로
        $return_url = home_url();
    }
}

// 로그인 실패 시 처리
$login_error = isset($_GET['login_error']) ? sanitize_text_field($_GET['login_error']) : '';
$error_message = '';
if (!empty($login_error)) {
    switch ($login_error) {
        case 'token':
            $error_message = '토큰 발급에 실패했습니다. 다시 시도해주세요.';
            break;
        case 'user_info':
            $error_message = '사용자 정보를 가져오는데 실패했습니다. 다시 시도해주세요.';
            break;
        case 'auth':
            $error_message = '인증에 실패했습니다. 다시 시도해주세요.';
            break;
        default:
            $error_message = '로그인 중 오류가 발생했습니다. 다시 시도해주세요.';
            break;
    }
}

// 카카오 인증 URL 생성
$auth_url = 'https://kauth.kakao.com/oauth/authorize';
$auth_url .= '?client_id=' . urlencode($client_id);
$auth_url .= '&redirect_uri=' . urlencode($redirect_uri);
$auth_url .= '&response_type=code';
$auth_url .= '&state=' . urlencode($return_url);

// 디버그 로그
wp_kakao_login_debug_log('Kakao Login URL: ' . $auth_url);
wp_kakao_login_debug_log('Return URL: ' . $return_url);

// HTML 출력
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>카카오 로그인 - <?php bloginfo('name'); ?></title>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <style>
        body, html {
            margin: 0;
            padding: 0;
            font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif;
            height: 100%;
            background-color: #f5f5f5;
        }
        .kakao-login-container {
            display: flex;
            flex-direction: column;
            height: 100%;
            justify-content: center;
            align-items: center;
            padding: 20px;
        }
        .kakao-login-box {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 12px rgba(0, 0, 0, 0.1);
            padding: 40px;
            width: 100%;
            max-width: 400px;
            text-align: center;
        }
        .kakao-login-logo {
            margin-bottom: 20px;
        }
        .kakao-login-logo img {
            height: 60px;
            width: auto;
        }
        .kakao-login-title {
            font-size: 24px;
            font-weight: 600;
            margin-bottom: 10px;
            color: #333;
        }
        .kakao-login-desc {
            color: #777;
            margin-bottom: 30px;
        }
        .kakao-login-button-wrap {
            margin-bottom: 20px;
        }
        .kakao-login-button {
            display: block;
            background-color: #FEE500;
            color: #000;
            padding: 15px 20px;
            border-radius: 6px;
            text-decoration: none;
            font-weight: 500;
            font-size: 16px;
            transition: all 0.3s ease;
            text-align: center;
        }
        .kakao-login-button:hover {
            background-color: #F6E000;
            box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
        }
        .kakao-login-button i {
            margin-right: 8px;
            font-size: 18px;
        }
        .kakao-login-or {
            position: relative;
            text-align: center;
            margin: 25px 0;
        }
        .kakao-login-or:before {
            content: "";
            position: absolute;
            top: 50%;
            left: 0;
            width: 100%;
            height: 1px;
            background-color: #e5e5e5;
            z-index: 1;
        }
        .kakao-login-or span {
            display: inline-block;
            position: relative;
            background-color: #fff;
            padding: 0 15px;
            color: #999;
            font-size: 14px;
            z-index: 2;
        }
        .kakao-login-wp-link a {
            color: #0073aa;
            text-decoration: none;
            font-size: 15px;
        }
        .kakao-login-wp-link a:hover {
            color: #00a0d2;
            text-decoration: underline;
        }
        .kakao-login-footer {
            margin-top: 30px;
            text-align: center;
            color: #999;
            font-size: 13px;
        }
        .error-message {
            background-color: #f8d7da;
            color: #721c24;
            padding: 10px;
            border-radius: 4px;
            margin-bottom: 20px;
            text-align: center;
        }
    </style>
</head>
<body>
    <div class="kakao-login-container">
        <div class="kakao-login-box">
            <?php if (!empty($error_message)): ?>
            <div class="error-message">
                <?php echo esc_html($error_message); ?>
            </div>
            <?php endif; ?>
            
            <div class="kakao-login-logo">
                <img src="https://developers.kakao.com/assets/img/about/logos/kakaolink/kakaolink_btn_medium.png" alt="카카오 로고">
            </div>
            <h2 class="kakao-login-title">카카오 계정으로 로그인</h2>
            <p class="kakao-login-desc">카카오톡으로 간편하게 로그인하고 다양한 서비스를 이용해보세요.</p>
            
            <div class="kakao-login-button-wrap">
                <a href="<?php echo esc_url($auth_url); ?>" class="kakao-login-button">
                    <i class="bi bi-chat-fill"></i> 카카오 계정으로 로그인
                </a>
            </div>
            
            <div class="kakao-login-or">
                <span>또는</span>
            </div>
            
            <div class="kakao-login-wp-link">
                <a href="<?php echo esc_url(wp_login_url($return_url)); ?>">일반 계정으로 로그인</a>
            </div>
        </div>
        
        <div class="kakao-login-footer">
            <p>&copy; <?php echo date('Y'); ?> <?php echo get_bloginfo('name'); ?>. All Rights Reserved.</p>
        </div>
    </div>
</body>
</html>
<?php
exit;