<?php
/*
 * 파일명: wp-kakao-login.php
 * 위치: /wp-content/plugins/wp-kakao-login/
 * 기능: 워드프레스 카카오 로그인 플러그인 메인 파일
 * 작성일: 2025-05-01
 * 수정일: 2025-05-02
 */

/*
Plugin Name: WP Kakao Login
Plugin URI: https://url.kr/p/wp-plugin/wp-kakao-login
Description: 카카오톡 소셜 로그인 기능을 워드프레스에 추가합니다.
Version: 1.0.0
Author: 호텔천사
Author URI: https://webworks.co.kr
License: GPL-2.0+
License URI: http://www.gnu.org/licenses/gpl-2.0.txt
Text Domain: wp-kakao-login
Domain Path: /languages
*/

// 직접 접근 방지
if (!defined('ABSPATH')) {
    exit;
}

// ===================================
// 플러그인 상수 정의
// ===================================
define('WP_KAKAO_LOGIN_VERSION', '1.0.0');
define('WP_KAKAO_LOGIN_PLUGIN_FILE', __FILE__);
define('WP_KAKAO_LOGIN_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('WP_KAKAO_LOGIN_PLUGIN_URL', plugin_dir_url(__FILE__));
define('WP_KAKAO_LOGIN_PLUGIN_BASENAME', plugin_basename(__FILE__));

// ===================================
// 필요한 파일 포함
// ===================================
require_once(WP_KAKAO_LOGIN_PLUGIN_DIR . 'includes/functions.php');
require_once(WP_KAKAO_LOGIN_PLUGIN_DIR . 'includes/class-kakao-login.php');

// 관리자 페이지인 경우만 관리자 클래스 로드
if (is_admin()) {
    require_once(WP_KAKAO_LOGIN_PLUGIN_DIR . 'includes/admin/class-kakao-admin.php');
    new WP_Kakao_Admin();
}

// ===================================
// 플러그인 활성화/비활성화 훅
// ===================================
// 활성화 시 실행할 함수
function wp_kakao_login_activate() {
    // 기본 설정값 추가
    $default_options = array(
        'kakao_client_id' => '',
        'kakao_client_secret' => '',
        'kakao_redirect_uri' => home_url('/kakao-callback'),
        'login_button_text' => '카카오 계정으로 로그인',
    );
    
    add_option('wp_kakao_login_options', $default_options);
    
    // 필요한 디렉토리 생성
    $css_dir = WP_KAKAO_LOGIN_PLUGIN_DIR . 'assets/css';
    $js_dir = WP_KAKAO_LOGIN_PLUGIN_DIR . 'assets/js';
    $img_dir = WP_KAKAO_LOGIN_PLUGIN_DIR . 'assets/images';
    $log_dir = WP_KAKAO_LOGIN_PLUGIN_DIR . 'logs';
    
    // CSS 디렉토리 생성
    if (!file_exists($css_dir)) {
        wp_mkdir_p($css_dir);
    }
    
    // JS 디렉토리 생성
    if (!file_exists($js_dir)) {
        wp_mkdir_p($js_dir);
    }
    
    // 이미지 디렉토리 생성
    if (!file_exists($img_dir)) {
        wp_mkdir_p($img_dir);
    }
    
    // 로그 디렉토리 생성 (디버깅용)
    if (!file_exists($log_dir)) {
        wp_mkdir_p($log_dir);
    }
    
    // 디버그 로그 파일 생성
    $log_file = $log_dir . '/debug.log';
    if (!file_exists($log_file)) {
        file_put_contents($log_file, '');
    }
    
    // 기본 CSS 파일 생성
    $css_file = $css_dir . '/kakao-login.css';
    if (!file_exists($css_file)) {
        $css_content = "
/*
 * 파일명: kakao-login.css
 * 위치: /wp-content/plugins/wp-kakao-login/assets/css/
 * 기능: 카카오 로그인 스타일
 * 작성일: 2025-05-01
 * 수정일: 2025-05-02
 */

/* ===================================
 * 기본 스타일
 * ===================================
 */
.kakao-login-wrap {
    margin: 20px 0;
    width: 100%;
}

/* 로그인 버튼 */
#kakao-login-btn, 
.kakao-login-btn {
    background-color: #FEE500 !important;
    color: #000000 !important;
    font-weight: bold !important;
    border: 1px solid #FEE500 !important;
    cursor: pointer;
    transition: all 0.3s ease;
    font-size: 14px;
    padding: 10px 15px;
    min-height: 45px;
    text-align: center;
    width: 100%;
    display: block;
    border-radius: 6px !important;
    text-decoration: none;
}

/* 버튼 호버/포커스 상태 */
#kakao-login-btn:hover, 
.kakao-login-btn:hover, 
#kakao-login-btn:focus,
.kakao-login-btn:focus {
    background-color: #F6E000 !important;
    box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1) !important;
    color: #3A1D1D !important;
}

/* 로그인 또는 구분선 */
.kakao-login-or {
    position: relative;
    text-align: center;
    margin: 15px 0;
}

.kakao-login-or:before {
    content: \"\";
    position: absolute;
    top: 50%;
    left: 0;
    width: 100%;
    height: 1px;
    background-color: #E5E5E5;
    z-index: 1;
}

.kakao-login-or span {
    display: inline-block;
    position: relative;
    background-color: #FFFFFF;
    padding: 0 10px;
    color: #767676;
    font-size: 13px;
    z-index: 2;
}

/* ===================================
 * 입력 그룹 스타일
 * ===================================
 */
.kakao-login-wrap .input-group {
    display: flex;
    width: 100%;
}

.kakao-login-wrap .input-group-text {
    border-right: none !important;
    background-color: #FFFFFF !important;
    display: flex;
    align-items: center;
    padding: 8px 12px;
    border: 1px solid #ccc;
    border-radius: 4px 0 0 4px;
}

.kakao-login-wrap .form-control {
    border-left: none !important;
    padding-left: 0 !important;
    flex: 1;
    border: 1px solid #ccc;
    border-radius: 0 4px 4px 0;
}

/* 아이콘 색상 */
.bi-chat-fill {
    color: #000000;
    font-size: 16px;
}

/* ===================================
 * 프로필 이미지
 * ===================================
 */
.kakao-profile-image {
    max-width: 100px;
    border-radius: 50%;
    border: 1px solid #E5E5E5;
}

/* ===================================
 * 모바일 최적화
 * ===================================
 */
@media (max-width: 768px) {
    #kakao-login-btn,
    .kakao-login-btn {
        font-size: 13px;
        padding: 8px 12px;
    }
    
    .kakao-login-wrap {
        margin: 15px 0;
    }
}

/* ===================================
 * 다크 모드 지원
 * ===================================
 */
@media (prefers-color-scheme: dark) {
    .kakao-login-or span {
        background-color: #202124;
        color: #ABABAB;
    }
    
    .kakao-login-btn {
        color: #3A1D1D !important;
    }
}

/* ===================================
 * WooCommerce 통합
 * ===================================
 */
.woocommerce-form-login .kakao-login-wrap,
.woocommerce-form-register .kakao-login-wrap {
    margin: 10px 0 20px;
}

/* ===================================
 * 애니메이션 효과
 * ===================================
 */
@keyframes kakao-button-pulse {
    0% {
        transform: scale(1);
    }
    50% {
        transform: scale(1.02);
    }
    100% {
        transform: scale(1);
    }
}

.kakao-login-btn:active {
    animation: kakao-button-pulse 0.3s;
}

/* ===================================
 * 단축코드 버튼 스타일
 * ===================================
 */
.kakao-shortcode-btn {
    display: inline-block;
    margin: 10px 0;
    width: 100%;
}
";
        file_put_contents($css_file, $css_content);
    }
    
    // 기본 JS 파일 생성
    $js_file = $js_dir . '/kakao-login.js';
    if (!file_exists($js_file)) {
        $js_content = "
/**
 * 파일명: kakao-login.js
 * 위치: /wp-content/plugins/wp-kakao-login/assets/js/
 * 기능: 카카오 로그인 JavaScript 기능
 * 작성일: 2025-05-01
 * 수정일: 2025-05-02
 */

(function($) {
    'use strict';
    
    // 페이지 로드 완료 시 실행
    $(document).ready(function() {
        console.log('Kakao Login Script Loaded');
        
        // 카카오 SDK 초기화
        if (typeof Kakao !== 'undefined' && wpKakaoLogin.apiKey) {
            console.log('Initializing Kakao SDK');
            Kakao.init(wpKakaoLogin.apiKey);
            console.log('Kakao SDK Initialized:', Kakao.isInitialized());
        } else {
            console.error('Kakao SDK is missing or API key is not set');
            return;
        }
    });
})(jQuery);
";
        file_put_contents($js_file, $js_content);
    }
}
register_activation_hook(WP_KAKAO_LOGIN_PLUGIN_FILE, 'wp_kakao_login_activate');

// 비활성화 시 실행할 함수
function wp_kakao_login_deactivate() {
    // 필요한 비활성화 작업 수행
}
register_deactivation_hook(WP_KAKAO_LOGIN_PLUGIN_FILE, 'wp_kakao_login_deactivate');

// ===================================
// 플러그인 초기화
// ===================================
function wp_kakao_login_init() {
    // 카카오 로그인 클래스 인스턴스 생성
    $kakao_login = new WP_Kakao_Login();
    
    // 스크립트 및 스타일 등록
    add_action('wp_enqueue_scripts', 'wp_kakao_login_enqueue_scripts');
    
    // 로그인 폼에 카카오 로그인 버튼 추가
    add_action('login_form', array($kakao_login, 'add_kakao_login_button'));
    add_action('register_form', array($kakao_login, 'add_kakao_login_button'));
    
    // 단축코드 등록
    add_shortcode('kakao_login_button', 'wp_kakao_login_shortcode');
}
add_action('init', 'wp_kakao_login_init');

// ===================================
// 스크립트 및 스타일 등록
// ===================================
function wp_kakao_login_enqueue_scripts() {
    // Bootstrap Icons CSS 로드
    wp_enqueue_style(
        'bootstrap-icons',
        'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css',
        array(),
        WP_KAKAO_LOGIN_VERSION
    );
    
    // 플러그인 스타일 등록 - 의존성 없이 최우선 로드되도록 설정
    wp_enqueue_style(
        'wp-kakao-login',
        WP_KAKAO_LOGIN_PLUGIN_URL . 'assets/css/kakao-login.css',
        array(),
        WP_KAKAO_LOGIN_VERSION . '.' . time() // 캐시 방지를 위한 버전 추가
    );
    
    // 카카오 자바스크립트 SDK 등록
    wp_enqueue_script(
        'kakao-sdk', 
        'https://developers.kakao.com/sdk/js/kakao.min.js', 
        array(), 
        WP_KAKAO_LOGIN_VERSION, 
        true
    );
    
    // 플러그인 자바스크립트 등록
    wp_enqueue_script(
        'wp-kakao-login', 
        WP_KAKAO_LOGIN_PLUGIN_URL . 'assets/js/kakao-login.js', 
        array('jquery', 'kakao-sdk'), 
        WP_KAKAO_LOGIN_VERSION . '.' . time(), // 캐시 방지를 위한 버전 추가
        true
    );
    
    // 스크립트에 필요한 변수 전달
    $options = get_option('wp_kakao_login_options');
    wp_localize_script('wp-kakao-login', 'wpKakaoLogin', array(
        'apiKey' => isset($options['kakao_client_id']) ? $options['kakao_client_id'] : '',
        'redirectUri' => isset($options['kakao_redirect_uri']) ? $options['kakao_redirect_uri'] : home_url('/kakao-callback'),
        'ajaxUrl' => admin_url('admin-ajax.php'),
        'nonce' => wp_create_nonce('wp_kakao_login_nonce'),
        'pluginUrl' => WP_KAKAO_LOGIN_PLUGIN_URL
    ));
}

// ===================================
// 로그인 페이지 스크립트 및 스타일
// ===================================
function wp_kakao_login_login_enqueue_scripts() {
    // 워드프레스 로그인 페이지에 jQuery 추가
    wp_enqueue_script('jquery');
    
    // 카카오 SDK 추가
    wp_enqueue_script(
        'kakao-sdk', 
        'https://developers.kakao.com/sdk/js/kakao.min.js', 
        array(), 
        WP_KAKAO_LOGIN_VERSION, 
        true
    );
}
add_action('login_enqueue_scripts', 'wp_kakao_login_login_enqueue_scripts');

// ===================================
// 단축코드 기능
// ===================================
function wp_kakao_login_shortcode($atts) {
    // 속성 기본값 설정
    $attributes = shortcode_atts(
        array(
            'text' => '',
            'redirect' => ''
        ),
        $atts
    );
    
    // 이미 로그인한 사용자는 로그인 버튼 대신 다른 내용 표시
    if (is_user_logged_in()) {
        $current_user = wp_get_current_user();
        return '<div class="kakao-login-wrap kakao-already-logged-in">
            <p>' . sprintf(__('안녕하세요, %s님!', 'wp-kakao-login'), $current_user->display_name) . '</p>
            <a href="' . wp_logout_url(home_url()) . '" class="kakao-logout-link">' . __('로그아웃', 'wp-kakao-login') . '</a>
        </div>';
    }
    
    // 직접 접근 페이지 URL
    $plugin_url = plugin_dir_url(WP_KAKAO_LOGIN_PLUGIN_FILE);
    $direct_kakao_login_url = $plugin_url . 'direct-kakao-login.php';
    
    // 리다이렉트 URL
    $redirect_url = !empty($attributes['redirect']) ? $attributes['redirect'] : home_url();
    $redirect_param = '?redirect_to=' . urlencode($redirect_url);
    
    // 버튼 텍스트 설정
    $options = get_option('wp_kakao_login_options');
    $button_text = !empty($attributes['text']) ? 
                   $attributes['text'] : 
                   (!empty($options['login_button_text']) ? $options['login_button_text'] : '카카오 계정으로 로그인');
    
    // 출력 버퍼링 시작
    ob_start();
    
    // 버튼 HTML 생성 - 간단한 스타일로
    echo '<p style="text-align:center;margin:10px 0;">';
    echo '<a href="' . esc_url($direct_kakao_login_url . $redirect_param) . '" style="display:inline-block;width:100%;padding:10px 0;background:#FEE500;color:#000;text-align:center;text-decoration:none;font-weight:bold;">';
    echo esc_html($button_text);
    echo '</a>';
    echo '</p>';
    
    // 버퍼 내용 반환
    return ob_get_clean();
}

// ===================================
// 국제화 (다국어 지원)
// ===================================
function wp_kakao_login_load_textdomain() {
    load_plugin_textdomain('wp-kakao-login', false, dirname(WP_KAKAO_LOGIN_PLUGIN_BASENAME) . '/languages');
}
add_action('plugins_loaded', 'wp_kakao_login_load_textdomain');

// ===================================
// 사용자 프로필에 카카오 연결 정보 표시
// ===================================
function wp_kakao_login_user_profile_fields($user) {
    // 카카오 연결 여부 확인
    $kakao_id = get_user_meta($user->ID, 'kakao_id', true);
    ?>
    <h3><?php _e('카카오 계정 연결', 'wp-kakao-login'); ?></h3>
    <table class="form-table">
        <tr>
            <th><label for="kakao_id"><?php _e('카카오 연결 상태', 'wp-kakao-login'); ?></label></th>
            <td>
                <?php if (!empty($kakao_id)) : ?>
                    <span class="description"><?php _e('카카오 계정이 연결되어 있습니다.', 'wp-kakao-login'); ?></span>
                    <br>
                    <a href="<?php echo wp_nonce_url(admin_url('admin-post.php?action=wp_kakao_disconnect'), 'wp_kakao_disconnect_' . $user->ID); ?>" 
                       class="button" onclick="return confirm('<?php _e('카카오 계정 연결을 해제하시겠습니까?', 'wp-kakao-login'); ?>');">
                        <?php _e('연결 해제', 'wp-kakao-login'); ?>
                    </a>
                <?php else : ?>
                    <span class="description"><?php _e('카카오 계정이 연결되어 있지 않습니다.', 'wp-kakao-login'); ?></span>
                    <br>
                    <?php
                    // 직접 접근 페이지 URL
                    $plugin_url = plugin_dir_url(WP_KAKAO_LOGIN_PLUGIN_FILE);
                    $direct_kakao_login_url = $plugin_url . 'direct-kakao-login.php';
                    $redirect_param = '?redirect_to=' . urlencode(admin_url('profile.php'));
                    ?>
                    <a href="<?php echo esc_url($direct_kakao_login_url . $redirect_param); ?>" class="button">
                        <?php _e('카카오 계정 연결하기', 'wp-kakao-login'); ?>
                    </a>
                <?php endif; ?>
            </td>
        </tr>
    </table>
    <?php
}
add_action('show_user_profile', 'wp_kakao_login_user_profile_fields');
add_action('edit_user_profile', 'wp_kakao_login_user_profile_fields');

// ===================================
// 카카오 계정 연결 해제 처리
// ===================================
function wp_kakao_login_disconnect() {
    // 권한 확인
    $user_id = get_current_user_id();
    if (!$user_id) {
        wp_die(__('권한이 없습니다.', 'wp-kakao-login'));
    }
    
    // 보안 확인
    check_admin_referer('wp_kakao_disconnect_' . $user_id);
    
    // 카카오 연결 삭제
    delete_user_meta($user_id, 'kakao_id');
    
    // 리다이렉트
    wp_redirect(admin_url('profile.php?updated=1'));
    exit;
}
add_action('admin_post_wp_kakao_disconnect', 'wp_kakao_login_disconnect');

// ===================================
// 디버그 로깅 기능
// ===================================
function wp_kakao_login_debug_log($message) {
    // 디버그 모드 확인 (나중에 관리자 설정으로 변경 가능)
    $debug_enabled = apply_filters('wp_kakao_login_debug_enabled', true);
    
    if ($debug_enabled) {
        // 로그 파일 경로
        $log_file = WP_KAKAO_LOGIN_PLUGIN_DIR . 'logs/debug.log';
        
        // 메시지 포맷팅
        $log_message = '[' . date('Y-m-d H:i:s') . '] ' . $message . PHP_EOL;
        
        // 로그 기록
        error_log($log_message, 3, $log_file);
    }
}